@@ -1,6 +1,6 @@
 package Markdent::Types;
 {
-  $Markdent::Types::VERSION = '0.19';
+  $Markdent::Types::VERSION = '0.20';
 }
 
 use strict;
@@ -9,8 +9,10 @@ use warnings;
 use base 'MooseX::Types::Combine';
 
 __PACKAGE__->provide_types_from(
-    qw( Markdent::Types::Internal
-        MooseX::Types::Moose )
+    qw(
+        Markdent::Types::Internal
+        MooseX::Types::Moose
+        )
 );
 
 1;
